@@ -77,7 +77,7 @@ func TestGitLabReleaseURLTemplate(t *testing.T) {
 				GitLab: tt.repo,
 			},
 		})
-		client, err := NewGitLab(ctx, ctx.Token)
+		client, err := newGitLab(ctx, ctx.Token)
 		require.NoError(t, err)
 
 		urlTpl, err := client.ReleaseURLTemplate(ctx)
@@ -123,13 +123,9 @@ func TestGitLabURLsAPITemplate(t *testing.T) {
 				GitLabURLs: gitlabURLs,
 			})
 
-			client, err := NewGitLab(ctx, ctx.Token)
+			client, err := newGitLab(ctx, ctx.Token)
 			require.NoError(t, err)
-
-			gitlabClient, ok := client.(*gitlabClient)
-			require.True(t, ok)
-
-			require.Equal(t, tt.wantHost, gitlabClient.client.BaseURL().Host)
+			require.Equal(t, tt.wantHost, client.client.BaseURL().Host)
 		})
 	}
 
@@ -140,7 +136,7 @@ func TestGitLabURLsAPITemplate(t *testing.T) {
 			},
 		})
 
-		_, err := NewGitLab(ctx, ctx.Token)
+		_, err := newGitLab(ctx, ctx.Token)
 		require.ErrorAs(t, err, &template.ExecError{})
 	})
 
@@ -151,7 +147,7 @@ func TestGitLabURLsAPITemplate(t *testing.T) {
 			},
 		})
 
-		_, err := NewGitLab(ctx, ctx.Token)
+		_, err := newGitLab(ctx, ctx.Token)
 		require.Error(t, err)
 	})
 }
@@ -240,7 +236,7 @@ func TestGitLabURLsDownloadTemplate(t *testing.T) {
 			tmpFile, err := os.CreateTemp(t.TempDir(), "")
 			require.NoError(t, err)
 
-			client, err := NewGitLab(ctx, ctx.Token)
+			client, err := newGitLab(ctx, ctx.Token)
 			require.NoError(t, err)
 
 			err = client.Upload(ctx, "1234", &artifact.Artifact{Name: "test", Path: "some-path"}, tmpFile)
@@ -265,7 +261,7 @@ func TestGitLabCreateReleaseUknownHost(t *testing.T) {
 			API: "http://goreleaser-notexists",
 		},
 	})
-	client, err := NewGitLab(ctx, "test-token")
+	client, err := newGitLab(ctx, "test-token")
 	require.NoError(t, err)
 
 	_, err = client.CreateRelease(ctx, "body")
@@ -313,13 +309,13 @@ func TestGitLabCreateReleaseReleaseNotExists(t *testing.T) {
 					API: srv.URL,
 				},
 			})
-			client, err := NewGitLab(ctx, "test-token")
+			client, err := newGitLab(ctx, "test-token")
 			require.NoError(t, err)
 
 			_, err = client.CreateRelease(ctx, "body")
 			require.NoError(t, err)
 			require.True(t, createdRelease)
-			require.Equal(t, 3, totalRequests)
+			require.Equal(t, 2, totalRequests)
 		})
 	}
 }
@@ -369,13 +365,13 @@ func TestGitLabCreateReleaseReleaseExists(t *testing.T) {
 			ReleaseNotesMode: config.ReleaseNotesModeKeepExisting,
 		},
 	})
-	client, err := NewGitLab(ctx, "test-token")
+	client, err := newGitLab(ctx, "test-token")
 	require.NoError(t, err)
 
 	_, err = client.CreateRelease(ctx, "body")
 	require.NoError(t, err)
 	require.True(t, createdRelease)
-	require.Equal(t, 3, totalRequests)
+	require.Equal(t, 2, totalRequests)
 }
 
 func TestGitLabCreateReleaseUnkownHTTPError(t *testing.T) {
@@ -394,12 +390,12 @@ func TestGitLabCreateReleaseUnkownHTTPError(t *testing.T) {
 			API: srv.URL,
 		},
 	})
-	client, err := NewGitLab(ctx, "test-token")
+	client, err := newGitLab(ctx, "test-token")
 	require.NoError(t, err)
 
 	_, err = client.CreateRelease(ctx, "body")
 	require.Error(t, err)
-	require.Equal(t, 2, totalRequests)
+	require.Equal(t, 1, totalRequests)
 }
 
 func TestGitlabGetDefaultBranch(t *testing.T) {
@@ -419,7 +415,7 @@ func TestGitlabGetDefaultBranch(t *testing.T) {
 			API: srv.URL,
 		},
 	})
-	client, err := NewGitLab(ctx, "test-token")
+	client, err := newGitLab(ctx, "test-token")
 	require.NoError(t, err)
 	repo := Repo{
 		Owner:  "someone",
@@ -427,9 +423,9 @@ func TestGitlabGetDefaultBranch(t *testing.T) {
 		Branch: "somebranch",
 	}
 
-	_, err = client.GetDefaultBranch(ctx, repo)
+	_, err = client.getDefaultBranch(ctx, repo)
 	require.NoError(t, err)
-	require.Equal(t, 2, totalRequests)
+	require.Equal(t, 1, totalRequests)
 }
 
 func TestGitlabGetDefaultBranchErr(t *testing.T) {
@@ -447,7 +443,7 @@ func TestGitlabGetDefaultBranchErr(t *testing.T) {
 			API: srv.URL,
 		},
 	})
-	client, err := NewGitLab(ctx, "test-token")
+	client, err := newGitLab(ctx, "test-token")
 	require.NoError(t, err)
 	repo := Repo{
 		Owner:  "someone",
@@ -455,7 +451,7 @@ func TestGitlabGetDefaultBranchErr(t *testing.T) {
 		Branch: "somebranch",
 	}
 
-	_, err = client.GetDefaultBranch(ctx, repo)
+	_, err = client.getDefaultBranch(ctx, repo)
 	require.Error(t, err)
 }
 
@@ -477,7 +473,7 @@ func TestGitlabChangelog(t *testing.T) {
 			API: srv.URL,
 		},
 	})
-	client, err := NewGitLab(ctx, "test-token")
+	client, err := newGitLab(ctx, "test-token")
 	require.NoError(t, err)
 	repo := Repo{
 		Owner:  "someone",
@@ -525,7 +521,7 @@ func TestGitlabCreateFile(t *testing.T) {
 		},
 	})
 
-	client, err := NewGitLab(ctx, "test-token")
+	client, err := newGitLab(ctx, "test-token")
 	require.NoError(t, err)
 
 	// Test using an arbitrary branch
@@ -583,7 +579,7 @@ func TestCloseMileston(t *testing.T) {
 			API: srv.URL,
 		},
 	})
-	client, err := NewGitLab(ctx, "test-token")
+	client, err := newGitLab(ctx, "test-token")
 	require.NoError(t, err)
 
 	repo := Repo{
