@@ -8,13 +8,16 @@ import (
 	"fmt"
 	"io"
 	"path/filepath"
+	"strconv"
 	"sync"
+	"time"
 
 	"github.com/awslabs/amazon-ecr-credential-helper/ecr-login"
 	"github.com/chrismellard/docker-credential-acr-env/pkg/credhelper"
 	"github.com/google/go-containerregistry/pkg/authn"
 	"github.com/google/go-containerregistry/pkg/authn/github"
 	"github.com/google/go-containerregistry/pkg/name"
+	v1 "github.com/google/go-containerregistry/pkg/v1"
 	"github.com/google/go-containerregistry/pkg/v1/google"
 	"github.com/google/go-containerregistry/pkg/v1/remote"
 	"github.com/google/ko/pkg/build"
@@ -138,7 +141,10 @@ type buildOptions struct {
 	workingDir          string
 	platforms           []string
 	baseImage           string
+	labels              map[string]string
 	tags                []string
+	creationTime        *v1.Time
+	koDataCreationTime  *v1.Time
 	sbom                string
 	ldflags             []string
 	bare                bool
@@ -187,6 +193,15 @@ func (o *buildOptions) makeBuilder(ctx *context.Context) (*build.Caching, error)
 			return nil, nil, fmt.Errorf("unexpected base image media type: %s", desc.MediaType)
 		}),
 	}
+	if o.creationTime != nil {
+		buildOptions = append(buildOptions, build.WithCreationTime(*o.creationTime))
+	}
+	if o.koDataCreationTime != nil {
+		buildOptions = append(buildOptions, build.WithKoDataCreationTime(*o.koDataCreationTime))
+	}
+	for k, v := range o.labels {
+		buildOptions = append(buildOptions, build.WithLabel(k, v))
+	}
 	switch o.sbom {
 	case "spdx":
 		buildOptions = append(buildOptions, build.WithSPDX("devel"))
@@ -299,6 +314,33 @@ func buildBuildOptions(ctx *context.Context, cfg config.Ko) (*buildOptions, erro
 	}
 	opts.tags = tags
 
+	if cfg.CreationTime != "" {
+		creationTime, err := getTimeFromTemplate(ctx, cfg.CreationTime)
+		if err != nil {
+			return nil, err
+		}
+		opts.creationTime = creationTime
+	}
+
+	if cfg.KoDataCreationTime != "" {
+		koDataCreationTime, err := getTimeFromTemplate(ctx, cfg.KoDataCreationTime)
+		if err != nil {
+			return nil, err
+		}
+		opts.koDataCreationTime = koDataCreationTime
+	}
+
+	if len(cfg.Labels) > 0 {
+		opts.labels = make(map[string]string, len(cfg.Labels))
+		for k, v := range cfg.Labels {
+			tv, err := tmpl.New(ctx).Apply(v)
+			if err != nil {
+				return nil, err
+			}
+			opts.labels[k] = tv
+		}
+	}
+
 	if len(cfg.Env) > 0 {
 		env, err := applyTemplate(ctx, cfg.Env)
 		if err != nil {
@@ -336,3 +378,16 @@ func applyTemplate(ctx *context.Context, templateable []string) ([]string, error
 	}
 	return templated, nil
 }
+
+func getTimeFromTemplate(ctx *context.Context, t string) (*v1.Time, error) {
+	epoch, err := tmpl.New(ctx).Apply(t)
+	if err != nil {
+		return nil, err
+	}
+
+	seconds, err := strconv.ParseInt(epoch, 10, 64)
+	if err != nil {
+		return nil, err
+	}
+	return &v1.Time{Time: time.Unix(seconds, 0)}, nil
+}
